@@ -87,6 +87,13 @@ class Router(Singleton):
         self.__lights = []
         self.__loadAllLights()
         self._t = None # Thread for websocket
+        # scheduler
+        self.scheduler = sched.scheduler(time.time, time.sleep)
+        self.__schedulerThread = Thread(
+            target=self.__runScheduler, args=(self.scheduler,)
+        )
+        self.__schedulerThread.daemon = True
+        self.__schedulerThread.start()
 
     def getAllGroups(self):
         return self.__groups
@@ -232,7 +239,7 @@ class Router(Singleton):
         else:
             logger.warning("obj not found, could not update state")
 
-    def __ws_on_message(self, message):
+    def __ws_on_message(self, wsapp, message):
         # print(message)
         try:
             obj = json.loads(message)
@@ -275,14 +282,14 @@ class Router(Singleton):
             logger.error(traceback.format_exc())
             logger.exception(error)
 
-    def __ws_on_error(self, error):
+    def __ws_on_error(self,wsapp, error):
         logger.error("### error ###")
         logger.error(error)
 
-    def __ws_on_close(self):
+    def __ws_on_close(self, wsapp):
         logger.info("### closed ###")
 
-    def __ws_on_open(self):
+    def __ws_on_open(self,wsapp):
         logger.info("### opened ###")
         logger.info(str(self))
         # print(str(ws))
@@ -315,13 +322,6 @@ class Router(Singleton):
         self._t.start()
         # _thread.start_new_thread( self._ws_thread_entry, ("Thread-1", 2, ) )
         # _thread.start_new_thread( self._ws_thread_entry, tuple() )
-        # scheduler
-        self.scheduler = sched.scheduler(time.time, time.sleep)
-        self.__schedulerThread = Thread(
-            target=self.__runScheduler, args=(self.scheduler,)
-        )
-        self.__schedulerThread.daemon = True
-        self.__schedulerThread.start()
 
     def __runScheduler(self, sched):
         maxSleep = 3
